==================
``scoring`` module
==================

.. automodule:: whoosh.scoring

Scoring algorithm classes
=========================

.. autoclass:: Weighting
    :members:

.. autoclass:: BM25F

.. autoclass:: TF_IDF

.. autoclass:: Frequency


Scoring utility classes
=======================

.. autoclass:: MultiWeighting

.. autoclass:: ReverseWeighting


Sorting classes
===============

.. autoclass:: Sorter

.. autoclass:: NullSorter

.. autoclass:: FieldSorter

.. autoclass:: MultiFieldSorter


